pub type CodeIterator<'a> = Box<dyn Iterator<Item = (Range<usize>, Code)> + 'a>;Expand description
An iterator over the highlighted regions of a line.
Each item is a character range within the line, paired with
the [Code] of the region.
Aliased Type
pub struct CodeIterator<'a>(/* private fields */);